﻿using FluentValidation;
using System;
using System.Collections.Generic;
using System.Text;

namespace Performance.DtoModels
{
    public class WorkloadRequest
    {
        /// <summary>
        /// 绩效ID
        /// </summary>
        public int Id { get; set; }
        /// <summary>
        /// 绩效ID
        /// </summary>
        public int AllotId { get; set; }

        /// <summary>
        /// 二次绩效ID
        /// </summary>
        public int SecondId { get; set; }

        /// <summary>
        /// 工作量名称
        /// </summary>
        public string ItemName { get; set; }

        /// <summary>
        /// 工作量系数
        /// </summary>
        public Nullable<decimal> FactorValue { get; set; }

        /// <summary>
        /// 
        /// </summary>
        public Nullable<decimal> Sort { get; set; }
    }
    public class WorkloadRequestValidator : AbstractValidator<WorkloadRequest>
    {
        public WorkloadRequestValidator()
        {
            RuleSet("Add", () =>
            {
                RuleFor(x => x.AllotId).NotNull().GreaterThan(0);
                RuleFor(x => x.SecondId).NotNull().GreaterThan(0);
                RuleFor(x => x.ItemName).NotNull().NotEmpty();
            });

            RuleSet("Update", () =>
            {
                RuleFor(x => x.Id).NotNull().GreaterThan(0);
                RuleFor(x => x.AllotId).NotNull().GreaterThan(0);
                RuleFor(x => x.SecondId).NotNull().GreaterThan(0);
                RuleFor(x => x.ItemName).NotNull().NotEmpty();
            });

            RuleSet("Delete", () =>
            {
                RuleFor(x => x.Id).NotNull().GreaterThan(0);
            });
            RuleSet("Query", () =>
            {
                RuleFor(x => x.SecondId).NotNull().GreaterThan(0);
            });
        }
    }
}
